@@ -54,10 +54,15 @@ class MprmWebsocket(MprmRest):
         while not self._connected and time.time() < start_time + 600:
             time.sleep(0.1)
         if not self._connected:
+            self._logger.debug("Websocket could not be established")
             raise GatewayOfflineError("Websocket could not be established.")
 
     def websocket_connect(self):
-        """ Set up the websocket connection. """
+        """
+        Set up the websocket connection. The procotol type of the known session URL is exchanged depending on whether TLS is
+        used or not. After establishing the websocket, a ping is sent every 30 seconds to keep the connection alive. If there
+        is no response within 5 seconds, the connection is terminated with error state.
+        """
         ws_url = self._session.url.replace("https://", "wss://").replace("http://", "ws://")
         cookie = "; ".join([str(name) + "=" + str(value) for name, value in self._session.cookies.items()])
         ws_url = f"{ws_url}/remote/events/?topics=com/prosyst/mbs/services/fim/FunctionalItemEvent/PROPERTY_CHANGED," \
@@ -70,11 +75,14 @@ class MprmWebsocket(MprmRest):
                                           on_message=self._on_message,
                                           on_error=self._on_error,
                                           on_close=self._on_close,
-                                          on_pong=self._on_pong)
+                                          on_pong=self._on_pong,
+                                          header={"Connection": "Upgrade"})
         self._ws.run_forever(ping_interval=30, ping_timeout=5)
 
     def websocket_disconnect(self, event: str = ""):
-        """ Close the websocket connection. """
+        """
+        Close the websocket connection.
+        """
         self._logger.info("Closing web socket connection.")
         if event != "":
             self._logger.info(f"Reason: {event}")
@@ -103,13 +111,15 @@ class MprmWebsocket(MprmRest):
     def _on_message(self, message: str):
         """ Callback method to react on a message. """
         message = json.loads(message)
-
+        self._logger.debug(f"Got message from websocket:\n{message}")
         event_sequence = message.get("properties").get("com.prosyst.mbs.services.remote.event.sequence.number")
         if event_sequence == self._event_sequence:
             self._event_sequence += 1
         else:
-            self._logger.warning("We missed a websocket message.")
-            self._event_sequence = event_sequence
+            self._logger.warning(f"We missed a websocket message. Internal event_sequence is at {self._event_sequence}. "
+                                 f"Event sequence by websocket is at {event_sequence}")
+            self._event_sequence = event_sequence + 1
+            self._logger.debug(f"self._event_sequence is set to {self._event_sequence}")
 
         self.on_update(message)
 
