@@ -1,9 +1,9 @@
 class MprmDeviceCommunicationError(Exception):
-    """ Communicating to a device via mPRM failed """
+    """ Communicating to a device via mPRM failed. """
 
 
 class MprmDeviceNotFoundError(Exception):
-    """ A device like this was not found """
+    """ A device like this was not found. """
 
 
 class WrongElementError(Exception):
